Workflow-to-tools
==================

.. automodule :: ephemeris.generate_tool_list_from_ga_workflow_files

Usage
----------

.. argparse::
   :module: ephemeris.generate_tool_list_from_ga_workflow_files
   :func: _parser
   :prog: workflow-to-tools
